@@ -1,8 +1,5 @@
-use std::fmt;
-use std::error;
-
 /// List of all errors.
-#[derive(Debug)]
+#[derive(Debug, PartialEq, Eq)]
 pub enum Error {
     /// An input data ended earlier than expected.
     ///
@@ -21,6 +18,13 @@ pub enum Error {
     /// then we will get `InvalidNumber`, because at least some data is valid.
     InvalidValue,
 
+    /// An invalid ident.
+    ///
+    /// CSS idents have certain rules with regard to the characters they may contain.
+    /// For example, they may not start with a number. If an invalid ident is encountered,
+    /// this error will be returned.
+    InvalidIdent,
+
     /// An invalid/unexpected character.
     ///
     /// The first byte is an actual one, others - expected.
@@ -37,13 +41,10 @@ pub enum Error {
 
     /// An invalid number.
     InvalidNumber(usize),
-
-    /// A viewBox with a negative or zero size.
-    InvalidViewbox,
 }
 
-impl fmt::Display for Error {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+impl std::fmt::Display for Error {
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
         match *self {
             Error::UnexpectedEndOfStream => {
                 write!(f, "unexpected end of stream")
@@ -54,33 +55,43 @@ impl fmt::Display for Error {
             Error::InvalidValue => {
                 write!(f, "invalid value")
             }
+            Error::InvalidIdent => {
+                write!(f, "invalid ident")
+            }
             Error::InvalidChar(ref chars, pos) => {
                 // Vec<u8> -> Vec<String>
-                let list: Vec<String> =
-                    chars.iter().skip(1).map(|c| String::from_utf8(vec![*c]).unwrap()).collect();
+                let list: Vec<String> = chars
+                    .iter()
+                    .skip(1)
+                    .map(|c| String::from_utf8(vec![*c]).unwrap())
+                    .collect();
 
-                write!(f, "expected '{}' not '{}' at position {}",
-                       list.join("', '"), chars[0] as char, pos)
+                write!(
+                    f,
+                    "expected '{}' not '{}' at position {}",
+                    list.join("', '"),
+                    chars[0] as char,
+                    pos
+                )
             }
             Error::InvalidString(ref strings, pos) => {
-                write!(f, "expected '{}' not '{}' at position {}",
-                       strings[1..].join("', '"), strings[0], pos)
+                write!(
+                    f,
+                    "expected '{}' not '{}' at position {}",
+                    strings[1..].join("', '"),
+                    strings[0],
+                    pos
+                )
             }
             Error::InvalidNumber(pos) => {
                 write!(f, "invalid number at position {}", pos)
             }
-            Error::InvalidViewbox => {
-                write!(f, "viewBox should have a positive size")
-            }
         }
     }
 }
 
-impl error::Error for Error {
+impl std::error::Error for Error {
     fn description(&self) -> &str {
         "an SVG data parsing error"
     }
 }
-
-/// An alias to `Result<T, Error>`.
-pub(crate) type Result<T> = ::std::result::Result<T, Error>;
